import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

void main() {
  runApp(new FontAwesomeGalleryApp());
}

class FontAwesomeGalleryApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      title: 'Font Awesome Flutter Gallery',
      theme: new ThemeData(
        iconTheme: new IconThemeData(size: 36.0, color: Colors.black87),
        primarySwatch: Colors.blueGrey,
        textTheme: new TextTheme(
          body1: new TextStyle(fontSize: 16.0, color: Colors.black87),
        ),
      ),
      home: new FontAwesomeGalleryHome(),
    );
  }
}

class FontAwesomeGalleryHome extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => new FontAwesomeGalleryHomeState();
}

class FontAwesomeGalleryHomeState extends State<FontAwesomeGalleryHome> {
  var searchTerm = "";
  var isSearching = false;

  @override
  Widget build(BuildContext context) {
    return new Scaffold(
      appBar: new AppBar(
        title: isSearching
            ? new TextField(
                onChanged: (text) => setState(() => searchTerm = text),
                autofocus: true,
                style: new TextStyle(fontSize: 18.0),
              )
            : new Text("Font Awesome Flutter Gallery"),
        actions: isSearching
            ? [
                new IconButton(
                    icon: new Icon(FontAwesomeIcons.timesCircle),
                    onPressed: () => setState(() {
                          isSearching = false;
                          searchTerm = "";
                        }))
              ]
            : [
                new IconButton(
                    icon: new Icon(FontAwesomeIcons.search),
                    onPressed: () => setState(() => isSearching = true))
              ],
      ),
      body: new GridView.count(
          crossAxisCount:
              MediaQuery.of(context).orientation == Orientation.portrait
                  ? 2
                  : 3,
          children: (icons..sort())
              .where((icon) =>
                  searchTerm.isEmpty ||
                  icon.title.toLowerCase().startsWith(searchTerm.toLowerCase()))
              .map((icon) => new InkWell(
                    onTap: () {
                      Navigator.push(
                        context,
                        new MaterialPageRoute<Null>(
                          builder: (BuildContext context) {
                            return new Container(
                              color: Colors.white,
                              child: new SizedBox.expand(
                                child: new Hero(
                                  tag: icon,
                                  child: new Icon(
                                    icon.iconData,
                                    size: 100.0,
                                  ),
                                ),
                              ),
                            );
                          },
                        ),
                      );
                    },
                    child: new Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        new Hero(tag: icon, child: new Icon(icon.iconData)),
                        new Container(
                            padding: new EdgeInsets.only(top: 16.0),
                            child: new Text(icon.title))
                      ],
                    ),
                  ))
              .toList()),
    );
  }
}

final List<IconDefinition> icons = <IconDefinition>[
  new IconDefinition(FontAwesomeIcons.glass, "glass"),
  new IconDefinition(FontAwesomeIcons.music, "music"),
  new IconDefinition(FontAwesomeIcons.search, "search"),
  new IconDefinition(FontAwesomeIcons.envelopeO, "envelopeO"),
  new IconDefinition(FontAwesomeIcons.heart, "heart"),
  new IconDefinition(FontAwesomeIcons.star, "star"),
  new IconDefinition(FontAwesomeIcons.starO, "starO"),
  new IconDefinition(FontAwesomeIcons.user, "user"),
  new IconDefinition(FontAwesomeIcons.film, "film"),
  new IconDefinition(FontAwesomeIcons.thLarge, "thLarge"),
  new IconDefinition(FontAwesomeIcons.th, "th"),
  new IconDefinition(FontAwesomeIcons.thList, "thList"),
  new IconDefinition(FontAwesomeIcons.check, "check"),
  new IconDefinition(FontAwesomeIcons.remove, "remove"),
  new IconDefinition(FontAwesomeIcons.close, "close"),
  new IconDefinition(FontAwesomeIcons.times, "times"),
  new IconDefinition(FontAwesomeIcons.searchPlus, "searchPlus"),
  new IconDefinition(FontAwesomeIcons.searchMinus, "searchMinus"),
  new IconDefinition(FontAwesomeIcons.powerOff, "powerOff"),
  new IconDefinition(FontAwesomeIcons.signal, "signal"),
  new IconDefinition(FontAwesomeIcons.gear, "gear"),
  new IconDefinition(FontAwesomeIcons.cog, "cog"),
  new IconDefinition(FontAwesomeIcons.trashO, "trashO"),
  new IconDefinition(FontAwesomeIcons.home, "home"),
  new IconDefinition(FontAwesomeIcons.fileO, "fileO"),
  new IconDefinition(FontAwesomeIcons.clockO, "clockO"),
  new IconDefinition(FontAwesomeIcons.road, "road"),
  new IconDefinition(FontAwesomeIcons.download, "download"),
  new IconDefinition(FontAwesomeIcons.arrowCircleODown, "arrowCircleODown"),
  new IconDefinition(FontAwesomeIcons.arrowCircleOUp, "arrowCircleOUp"),
  new IconDefinition(FontAwesomeIcons.inbox, "inbox"),
  new IconDefinition(FontAwesomeIcons.playCircleO, "playCircleO"),
  new IconDefinition(FontAwesomeIcons.rotateRight, "rotateRight"),
  new IconDefinition(FontAwesomeIcons.repeat, "repeat"),
  new IconDefinition(FontAwesomeIcons.refresh, "refresh"),
  new IconDefinition(FontAwesomeIcons.listAlt, "listAlt"),
  new IconDefinition(FontAwesomeIcons.lock, "lock"),
  new IconDefinition(FontAwesomeIcons.flag, "flag"),
  new IconDefinition(FontAwesomeIcons.headphones, "headphones"),
  new IconDefinition(FontAwesomeIcons.volumeOff, "volumeOff"),
  new IconDefinition(FontAwesomeIcons.volumeDown, "volumeDown"),
  new IconDefinition(FontAwesomeIcons.volumeUp, "volumeUp"),
  new IconDefinition(FontAwesomeIcons.qrcode, "qrcode"),
  new IconDefinition(FontAwesomeIcons.barcode, "barcode"),
  new IconDefinition(FontAwesomeIcons.tag, "tag"),
  new IconDefinition(FontAwesomeIcons.tags, "tags"),
  new IconDefinition(FontAwesomeIcons.book, "book"),
  new IconDefinition(FontAwesomeIcons.bookmark, "bookmark"),
  new IconDefinition(FontAwesomeIcons.print, "print"),
  new IconDefinition(FontAwesomeIcons.camera, "camera"),
  new IconDefinition(FontAwesomeIcons.font, "font"),
  new IconDefinition(FontAwesomeIcons.bold, "bold"),
  new IconDefinition(FontAwesomeIcons.italic, "italic"),
  new IconDefinition(FontAwesomeIcons.textHeight, "textHeight"),
  new IconDefinition(FontAwesomeIcons.textWidth, "textWidth"),
  new IconDefinition(FontAwesomeIcons.alignLeft, "alignLeft"),
  new IconDefinition(FontAwesomeIcons.alignCenter, "alignCenter"),
  new IconDefinition(FontAwesomeIcons.alignRight, "alignRight"),
  new IconDefinition(FontAwesomeIcons.alignJustify, "alignJustify"),
  new IconDefinition(FontAwesomeIcons.list, "list"),
  new IconDefinition(FontAwesomeIcons.dedent, "dedent"),
  new IconDefinition(FontAwesomeIcons.outdent, "outdent"),
  new IconDefinition(FontAwesomeIcons.indent, "indent"),
  new IconDefinition(FontAwesomeIcons.videoCamera, "videoCamera"),
  new IconDefinition(FontAwesomeIcons.photo, "photo"),
  new IconDefinition(FontAwesomeIcons.image, "image"),
  new IconDefinition(FontAwesomeIcons.pictureO, "pictureO"),
  new IconDefinition(FontAwesomeIcons.pencil, "pencil"),
  new IconDefinition(FontAwesomeIcons.mapMarker, "mapMarker"),
  new IconDefinition(FontAwesomeIcons.adjust, "adjust"),
  new IconDefinition(FontAwesomeIcons.tint, "tint"),
  new IconDefinition(FontAwesomeIcons.edit, "edit"),
  new IconDefinition(FontAwesomeIcons.pencilSquareO, "pencilSquareO"),
  new IconDefinition(FontAwesomeIcons.shareSquareO, "shareSquareO"),
  new IconDefinition(FontAwesomeIcons.checkSquareO, "checkSquareO"),
  new IconDefinition(FontAwesomeIcons.arrows, "arrows"),
  new IconDefinition(FontAwesomeIcons.stepBackward, "stepBackward"),
  new IconDefinition(FontAwesomeIcons.fastBackward, "fastBackward"),
  new IconDefinition(FontAwesomeIcons.backward, "backward"),
  new IconDefinition(FontAwesomeIcons.play, "play"),
  new IconDefinition(FontAwesomeIcons.pause, "pause"),
  new IconDefinition(FontAwesomeIcons.stop, "stop"),
  new IconDefinition(FontAwesomeIcons.forward, "forward"),
  new IconDefinition(FontAwesomeIcons.fastForward, "fastForward"),
  new IconDefinition(FontAwesomeIcons.stepForward, "stepForward"),
  new IconDefinition(FontAwesomeIcons.eject, "eject"),
  new IconDefinition(FontAwesomeIcons.chevronLeft, "chevronLeft"),
  new IconDefinition(FontAwesomeIcons.chevronRight, "chevronRight"),
  new IconDefinition(FontAwesomeIcons.plusCircle, "plusCircle"),
  new IconDefinition(FontAwesomeIcons.minusCircle, "minusCircle"),
  new IconDefinition(FontAwesomeIcons.timesCircle, "timesCircle"),
  new IconDefinition(FontAwesomeIcons.checkCircle, "checkCircle"),
  new IconDefinition(FontAwesomeIcons.questionCircle, "questionCircle"),
  new IconDefinition(FontAwesomeIcons.infoCircle, "infoCircle"),
  new IconDefinition(FontAwesomeIcons.crosshairs, "crosshairs"),
  new IconDefinition(FontAwesomeIcons.timesCircleO, "timesCircleO"),
  new IconDefinition(FontAwesomeIcons.checkCircleO, "checkCircleO"),
  new IconDefinition(FontAwesomeIcons.ban, "ban"),
  new IconDefinition(FontAwesomeIcons.arrowLeft, "arrowLeft"),
  new IconDefinition(FontAwesomeIcons.arrowRight, "arrowRight"),
  new IconDefinition(FontAwesomeIcons.arrowUp, "arrowUp"),
  new IconDefinition(FontAwesomeIcons.arrowDown, "arrowDown"),
  new IconDefinition(FontAwesomeIcons.mailForward, "mailForward"),
  new IconDefinition(FontAwesomeIcons.share, "share"),
  new IconDefinition(FontAwesomeIcons.expand, "expand"),
  new IconDefinition(FontAwesomeIcons.compress, "compress"),
  new IconDefinition(FontAwesomeIcons.plus, "plus"),
  new IconDefinition(FontAwesomeIcons.minus, "minus"),
  new IconDefinition(FontAwesomeIcons.asterisk, "asterisk"),
  new IconDefinition(FontAwesomeIcons.exclamationCircle, "exclamationCircle"),
  new IconDefinition(FontAwesomeIcons.gift, "gift"),
  new IconDefinition(FontAwesomeIcons.leaf, "leaf"),
  new IconDefinition(FontAwesomeIcons.fire, "fire"),
  new IconDefinition(FontAwesomeIcons.eye, "eye"),
  new IconDefinition(FontAwesomeIcons.eyeSlash, "eyeSlash"),
  new IconDefinition(FontAwesomeIcons.warning, "warning"),
  new IconDefinition(
      FontAwesomeIcons.exclamationTriangle, "exclamationTriangle"),
  new IconDefinition(FontAwesomeIcons.plane, "plane"),
  new IconDefinition(FontAwesomeIcons.calendar, "calendar"),
  new IconDefinition(FontAwesomeIcons.random, "random"),
  new IconDefinition(FontAwesomeIcons.comment, "comment"),
  new IconDefinition(FontAwesomeIcons.magnet, "magnet"),
  new IconDefinition(FontAwesomeIcons.chevronUp, "chevronUp"),
  new IconDefinition(FontAwesomeIcons.chevronDown, "chevronDown"),
  new IconDefinition(FontAwesomeIcons.retweet, "retweet"),
  new IconDefinition(FontAwesomeIcons.shoppingCart, "shoppingCart"),
  new IconDefinition(FontAwesomeIcons.folder, "folder"),
  new IconDefinition(FontAwesomeIcons.folderOpen, "folderOpen"),
  new IconDefinition(FontAwesomeIcons.arrowsV, "arrowsV"),
  new IconDefinition(FontAwesomeIcons.arrowsH, "arrowsH"),
  new IconDefinition(FontAwesomeIcons.barChartO, "barChartO"),
  new IconDefinition(FontAwesomeIcons.barChart, "barChart"),
  new IconDefinition(FontAwesomeIcons.twitterSquare, "twitterSquare"),
  new IconDefinition(FontAwesomeIcons.facebookSquare, "facebookSquare"),
  new IconDefinition(FontAwesomeIcons.cameraRetro, "cameraRetro"),
  new IconDefinition(FontAwesomeIcons.key, "key"),
  new IconDefinition(FontAwesomeIcons.gears, "gears"),
  new IconDefinition(FontAwesomeIcons.cogs, "cogs"),
  new IconDefinition(FontAwesomeIcons.comments, "comments"),
  new IconDefinition(FontAwesomeIcons.thumbsOUp, "thumbsOUp"),
  new IconDefinition(FontAwesomeIcons.thumbsODown, "thumbsODown"),
  new IconDefinition(FontAwesomeIcons.starHalf, "starHalf"),
  new IconDefinition(FontAwesomeIcons.heartO, "heartO"),
  new IconDefinition(FontAwesomeIcons.signOut, "signOut"),
  new IconDefinition(FontAwesomeIcons.linkedinSquare, "linkedinSquare"),
  new IconDefinition(FontAwesomeIcons.thumbTack, "thumbTack"),
  new IconDefinition(FontAwesomeIcons.externalLink, "externalLink"),
  new IconDefinition(FontAwesomeIcons.signIn, "signIn"),
  new IconDefinition(FontAwesomeIcons.trophy, "trophy"),
  new IconDefinition(FontAwesomeIcons.githubSquare, "githubSquare"),
  new IconDefinition(FontAwesomeIcons.upload, "upload"),
  new IconDefinition(FontAwesomeIcons.lemonO, "lemonO"),
  new IconDefinition(FontAwesomeIcons.phone, "phone"),
  new IconDefinition(FontAwesomeIcons.squareO, "squareO"),
  new IconDefinition(FontAwesomeIcons.bookmarkO, "bookmarkO"),
  new IconDefinition(FontAwesomeIcons.phoneSquare, "phoneSquare"),
  new IconDefinition(FontAwesomeIcons.twitter, "twitter"),
  new IconDefinition(FontAwesomeIcons.facebook, "facebook"),
  new IconDefinition(FontAwesomeIcons.github, "github"),
  new IconDefinition(FontAwesomeIcons.unlock, "unlock"),
  new IconDefinition(FontAwesomeIcons.creditCard, "creditCard"),
  new IconDefinition(FontAwesomeIcons.feed, "feed"),
  new IconDefinition(FontAwesomeIcons.rss, "rss"),
  new IconDefinition(FontAwesomeIcons.hddO, "hddO"),
  new IconDefinition(FontAwesomeIcons.bullhorn, "bullhorn"),
  new IconDefinition(FontAwesomeIcons.bell, "bell"),
  new IconDefinition(FontAwesomeIcons.certificate, "certificate"),
  new IconDefinition(FontAwesomeIcons.handORight, "handORight"),
  new IconDefinition(FontAwesomeIcons.handOLeft, "handOLeft"),
  new IconDefinition(FontAwesomeIcons.handOUp, "handOUp"),
  new IconDefinition(FontAwesomeIcons.handODown, "handODown"),
  new IconDefinition(FontAwesomeIcons.arrowCircleLeft, "arrowCircleLeft"),
  new IconDefinition(FontAwesomeIcons.arrowCircleRight, "arrowCircleRight"),
  new IconDefinition(FontAwesomeIcons.arrowCircleUp, "arrowCircleUp"),
  new IconDefinition(FontAwesomeIcons.arrowCircleDown, "arrowCircleDown"),
  new IconDefinition(FontAwesomeIcons.globe, "globe"),
  new IconDefinition(FontAwesomeIcons.wrench, "wrench"),
  new IconDefinition(FontAwesomeIcons.tasks, "tasks"),
  new IconDefinition(FontAwesomeIcons.filter, "filter"),
  new IconDefinition(FontAwesomeIcons.briefcase, "briefcase"),
  new IconDefinition(FontAwesomeIcons.arrowsAlt, "arrowsAlt"),
  new IconDefinition(FontAwesomeIcons.group, "group"),
  new IconDefinition(FontAwesomeIcons.users, "users"),
  new IconDefinition(FontAwesomeIcons.chain, "chain"),
  new IconDefinition(FontAwesomeIcons.link, "link"),
  new IconDefinition(FontAwesomeIcons.cloud, "cloud"),
  new IconDefinition(FontAwesomeIcons.flask, "flask"),
  new IconDefinition(FontAwesomeIcons.cut, "cut"),
  new IconDefinition(FontAwesomeIcons.scissors, "scissors"),
  new IconDefinition(FontAwesomeIcons.copy, "copy"),
  new IconDefinition(FontAwesomeIcons.filesO, "filesO"),
  new IconDefinition(FontAwesomeIcons.paperclip, "paperclip"),
  new IconDefinition(FontAwesomeIcons.save, "save"),
  new IconDefinition(FontAwesomeIcons.floppyO, "floppyO"),
  new IconDefinition(FontAwesomeIcons.square, "square"),
  new IconDefinition(FontAwesomeIcons.navIcon, "navIcon"),
  new IconDefinition(FontAwesomeIcons.reorder, "reorder"),
  new IconDefinition(FontAwesomeIcons.bars, "bars"),
  new IconDefinition(FontAwesomeIcons.listUl, "listUl"),
  new IconDefinition(FontAwesomeIcons.listOl, "listOl"),
  new IconDefinition(FontAwesomeIcons.strikethrough, "strikethrough"),
  new IconDefinition(FontAwesomeIcons.underline, "underline"),
  new IconDefinition(FontAwesomeIcons.table, "table"),
  new IconDefinition(FontAwesomeIcons.magic, "magic"),
  new IconDefinition(FontAwesomeIcons.truck, "truck"),
  new IconDefinition(FontAwesomeIcons.pinterest, "pinterest"),
  new IconDefinition(FontAwesomeIcons.pinterestSquare, "pinterestSquare"),
  new IconDefinition(FontAwesomeIcons.googlePlusSquare, "googlePlusSquare"),
  new IconDefinition(FontAwesomeIcons.googlePlus, "googlePlus"),
  new IconDefinition(FontAwesomeIcons.money, "money"),
  new IconDefinition(FontAwesomeIcons.caretDown, "caretDown"),
  new IconDefinition(FontAwesomeIcons.caretUp, "caretUp"),
  new IconDefinition(FontAwesomeIcons.caretLeft, "caretLeft"),
  new IconDefinition(FontAwesomeIcons.caretRight, "caretRight"),
  new IconDefinition(FontAwesomeIcons.columns, "columns"),
  new IconDefinition(FontAwesomeIcons.unsorted, "unsorted"),
  new IconDefinition(FontAwesomeIcons.sort, "sort"),
  new IconDefinition(FontAwesomeIcons.sortDown, "sortDown"),
  new IconDefinition(FontAwesomeIcons.sortDesc, "sortDesc"),
  new IconDefinition(FontAwesomeIcons.sortUp, "sortUp"),
  new IconDefinition(FontAwesomeIcons.sortAsc, "sortAsc"),
  new IconDefinition(FontAwesomeIcons.envelope, "envelope"),
  new IconDefinition(FontAwesomeIcons.linkedin, "linkedin"),
  new IconDefinition(FontAwesomeIcons.rotateLeft, "rotateLeft"),
  new IconDefinition(FontAwesomeIcons.undo, "undo"),
  new IconDefinition(FontAwesomeIcons.legal, "legal"),
  new IconDefinition(FontAwesomeIcons.gavel, "gavel"),
  new IconDefinition(FontAwesomeIcons.dashboard, "dashboard"),
  new IconDefinition(FontAwesomeIcons.tachometer, "tachometer"),
  new IconDefinition(FontAwesomeIcons.commentO, "commentO"),
  new IconDefinition(FontAwesomeIcons.commentsO, "commentsO"),
  new IconDefinition(FontAwesomeIcons.flash, "flash"),
  new IconDefinition(FontAwesomeIcons.bolt, "bolt"),
  new IconDefinition(FontAwesomeIcons.sitemap, "sitemap"),
  new IconDefinition(FontAwesomeIcons.umbrella, "umbrella"),
  new IconDefinition(FontAwesomeIcons.paste, "paste"),
  new IconDefinition(FontAwesomeIcons.clipboard, "clipboard"),
  new IconDefinition(FontAwesomeIcons.lightbulbO, "lightbulbO"),
  new IconDefinition(FontAwesomeIcons.exchange, "exchange"),
  new IconDefinition(FontAwesomeIcons.cloudDownload, "cloudDownload"),
  new IconDefinition(FontAwesomeIcons.cloudUpload, "cloudUpload"),
  new IconDefinition(FontAwesomeIcons.userMd, "userMd"),
  new IconDefinition(FontAwesomeIcons.stethoscope, "stethoscope"),
  new IconDefinition(FontAwesomeIcons.suitcase, "suitcase"),
  new IconDefinition(FontAwesomeIcons.bellO, "bellO"),
  new IconDefinition(FontAwesomeIcons.coffee, "coffee"),
  new IconDefinition(FontAwesomeIcons.cutlery, "cutlery"),
  new IconDefinition(FontAwesomeIcons.fileTextO, "fileTextO"),
  new IconDefinition(FontAwesomeIcons.buildingO, "buildingO"),
  new IconDefinition(FontAwesomeIcons.hospitalO, "hospitalO"),
  new IconDefinition(FontAwesomeIcons.ambulance, "ambulance"),
  new IconDefinition(FontAwesomeIcons.medkit, "medkit"),
  new IconDefinition(FontAwesomeIcons.fighterJet, "fighterJet"),
  new IconDefinition(FontAwesomeIcons.beer, "beer"),
  new IconDefinition(FontAwesomeIcons.hSquare, "hSquare"),
  new IconDefinition(FontAwesomeIcons.plusSquare, "plusSquare"),
  new IconDefinition(FontAwesomeIcons.angleDoubleLeft, "angleDoubleLeft"),
  new IconDefinition(FontAwesomeIcons.angleDoubleRight, "angleDoubleRight"),
  new IconDefinition(FontAwesomeIcons.angleDoubleUp, "angleDoubleUp"),
  new IconDefinition(FontAwesomeIcons.angleDoubleDown, "angleDoubleDown"),
  new IconDefinition(FontAwesomeIcons.angleLeft, "angleLeft"),
  new IconDefinition(FontAwesomeIcons.angleRight, "angleRight"),
  new IconDefinition(FontAwesomeIcons.angleUp, "angleUp"),
  new IconDefinition(FontAwesomeIcons.angleDown, "angleDown"),
  new IconDefinition(FontAwesomeIcons.desktop, "desktop"),
  new IconDefinition(FontAwesomeIcons.laptop, "laptop"),
  new IconDefinition(FontAwesomeIcons.tablet, "tablet"),
  new IconDefinition(FontAwesomeIcons.mobilePhone, "mobilePhone"),
  new IconDefinition(FontAwesomeIcons.circleO, "circleO"),
  new IconDefinition(FontAwesomeIcons.quoteLeft, "quoteLeft"),
  new IconDefinition(FontAwesomeIcons.quoteRight, "quoteRight"),
  new IconDefinition(FontAwesomeIcons.spinner, "spinner"),
  new IconDefinition(FontAwesomeIcons.circle, "circle"),
  new IconDefinition(FontAwesomeIcons.mailReply, "mailReply"),
  new IconDefinition(FontAwesomeIcons.reply, "reply"),
  new IconDefinition(FontAwesomeIcons.githubAlt, "githubAlt"),
  new IconDefinition(FontAwesomeIcons.folderO, "folderO"),
  new IconDefinition(FontAwesomeIcons.folderOpenO, "folderOpenO"),
  new IconDefinition(FontAwesomeIcons.smileO, "smileO"),
  new IconDefinition(FontAwesomeIcons.frownO, "frownO"),
  new IconDefinition(FontAwesomeIcons.mehO, "mehO"),
  new IconDefinition(FontAwesomeIcons.gamepad, "gamepad"),
  new IconDefinition(FontAwesomeIcons.keyboardO, "keyboardO"),
  new IconDefinition(FontAwesomeIcons.flagO, "flagO"),
  new IconDefinition(FontAwesomeIcons.flagCheckered, "flagCheckered"),
  new IconDefinition(FontAwesomeIcons.terminal, "terminal"),
  new IconDefinition(FontAwesomeIcons.code, "code"),
  new IconDefinition(FontAwesomeIcons.mailReplyAll, "mailReplyAll"),
  new IconDefinition(FontAwesomeIcons.replyAll, "replyAll"),
  new IconDefinition(FontAwesomeIcons.starHalfEmpty, "starHalfEmpty"),
  new IconDefinition(FontAwesomeIcons.starHalfFull, "starHalfFull"),
  new IconDefinition(FontAwesomeIcons.starHalfO, "starHalfO"),
  new IconDefinition(FontAwesomeIcons.locationArrow, "locationArrow"),
  new IconDefinition(FontAwesomeIcons.crop, "crop"),
  new IconDefinition(FontAwesomeIcons.codeFork, "codeFork"),
  new IconDefinition(FontAwesomeIcons.unlink, "unlink"),
  new IconDefinition(FontAwesomeIcons.chainBroken, "chainBroken"),
  new IconDefinition(FontAwesomeIcons.question, "question"),
  new IconDefinition(FontAwesomeIcons.info, "info"),
  new IconDefinition(FontAwesomeIcons.exclamation, "exclamation"),
  new IconDefinition(FontAwesomeIcons.superscript, "superscript"),
  new IconDefinition(FontAwesomeIcons.subscript, "subscript"),
  new IconDefinition(FontAwesomeIcons.eraser, "eraser"),
  new IconDefinition(FontAwesomeIcons.puzzlePiece, "puzzlePiece"),
  new IconDefinition(FontAwesomeIcons.microphone, "microphone"),
  new IconDefinition(FontAwesomeIcons.microphoneSlash, "microphoneSlash"),
  new IconDefinition(FontAwesomeIcons.shield, "shield"),
  new IconDefinition(FontAwesomeIcons.calendarO, "calendarO"),
  new IconDefinition(FontAwesomeIcons.fireExtinguisher, "fireExtinguisher"),
  new IconDefinition(FontAwesomeIcons.rocket, "rocket"),
  new IconDefinition(FontAwesomeIcons.maxcdn, "maxcdn"),
  new IconDefinition(FontAwesomeIcons.chevronCircleLeft, "chevronCircleLeft"),
  new IconDefinition(FontAwesomeIcons.chevronCircleRight, "chevronCircleRight"),
  new IconDefinition(FontAwesomeIcons.chevronCircleUp, "chevronCircleUp"),
  new IconDefinition(FontAwesomeIcons.chevronCircleDown, "chevronCircleDown"),
  new IconDefinition(FontAwesomeIcons.html5, "html5"),
  new IconDefinition(FontAwesomeIcons.css3, "css3"),
  new IconDefinition(FontAwesomeIcons.anchor, "anchor"),
  new IconDefinition(FontAwesomeIcons.unlockAlt, "unlockAlt"),
  new IconDefinition(FontAwesomeIcons.bullseye, "bullseye"),
  new IconDefinition(FontAwesomeIcons.ellipsisH, "ellipsisH"),
  new IconDefinition(FontAwesomeIcons.ellipsisV, "ellipsisV"),
  new IconDefinition(FontAwesomeIcons.rssSquare, "rssSquare"),
  new IconDefinition(FontAwesomeIcons.playCircle, "playCircle"),
  new IconDefinition(FontAwesomeIcons.ticket, "ticket"),
  new IconDefinition(FontAwesomeIcons.minusSquare, "minusSquare"),
  new IconDefinition(FontAwesomeIcons.minusSquareO, "minusSquareO"),
  new IconDefinition(FontAwesomeIcons.levelUp, "levelUp"),
  new IconDefinition(FontAwesomeIcons.levelDown, "levelDown"),
  new IconDefinition(FontAwesomeIcons.checkSquare, "checkSquare"),
  new IconDefinition(FontAwesomeIcons.pencilSquare, "pencilSquare"),
  new IconDefinition(FontAwesomeIcons.externalLinkSquare, "externalLinkSquare"),
  new IconDefinition(FontAwesomeIcons.shareSquare, "shareSquare"),
  new IconDefinition(FontAwesomeIcons.compass, "compass"),
  new IconDefinition(FontAwesomeIcons.toggleDown, "toggleDown"),
  new IconDefinition(FontAwesomeIcons.caretSquareODown, "caretSquareODown"),
  new IconDefinition(FontAwesomeIcons.toggleUp, "toggleUp"),
  new IconDefinition(FontAwesomeIcons.caretSquareOUp, "caretSquareOUp"),
  new IconDefinition(FontAwesomeIcons.caretSquareORight, "caretSquareORight"),
  new IconDefinition(FontAwesomeIcons.toggleRight, "toggleRight"),
  new IconDefinition(FontAwesomeIcons.eur, "eur"),
  new IconDefinition(FontAwesomeIcons.gbp, "gbp"),
  new IconDefinition(FontAwesomeIcons.dollar, "dollar"),
  new IconDefinition(FontAwesomeIcons.usd, "usd"),
  new IconDefinition(FontAwesomeIcons.inr, "inr"),
  new IconDefinition(FontAwesomeIcons.cny, "cny"),
  new IconDefinition(FontAwesomeIcons.rmb, "rmb"),
  new IconDefinition(FontAwesomeIcons.yen, "yen"),
  new IconDefinition(FontAwesomeIcons.jpy, "jpy"),
  new IconDefinition(FontAwesomeIcons.rub, "rub"),
  new IconDefinition(FontAwesomeIcons.won, "won"),
  new IconDefinition(FontAwesomeIcons.krw, "krw"),
  new IconDefinition(FontAwesomeIcons.bitcoin, "bitcoin"),
  new IconDefinition(FontAwesomeIcons.btc, "btc"),
  new IconDefinition(FontAwesomeIcons.file, "file"),
  new IconDefinition(FontAwesomeIcons.fileText, "fileText"),
  new IconDefinition(FontAwesomeIcons.sortAlphaAsc, "sortAlphaAsc"),
  new IconDefinition(FontAwesomeIcons.sortAlphaDesc, "sortAlphaDesc"),
  new IconDefinition(FontAwesomeIcons.sortAmountAsc, "sortAmountAsc"),
  new IconDefinition(FontAwesomeIcons.sortAmountDesc, "sortAmountDesc"),
  new IconDefinition(FontAwesomeIcons.sortNumericAsc, "sortNumericAsc"),
  new IconDefinition(FontAwesomeIcons.sortNumericDesc, "sortNumericDesc"),
  new IconDefinition(FontAwesomeIcons.thumbsUp, "thumbsUp"),
  new IconDefinition(FontAwesomeIcons.thumbsDown, "thumbsDown"),
  new IconDefinition(FontAwesomeIcons.youtubeSquare, "youtubeSquare"),
  new IconDefinition(FontAwesomeIcons.youtube, "youtube"),
  new IconDefinition(FontAwesomeIcons.xing, "xing"),
  new IconDefinition(FontAwesomeIcons.xingSquare, "xingSquare"),
  new IconDefinition(FontAwesomeIcons.youtubePlay, "youtubePlay"),
  new IconDefinition(FontAwesomeIcons.dropbox, "dropbox"),
  new IconDefinition(FontAwesomeIcons.stackOverflow, "stackOverflow"),
  new IconDefinition(FontAwesomeIcons.instagram, "instagram"),
  new IconDefinition(FontAwesomeIcons.flickr, "flickr"),
  new IconDefinition(FontAwesomeIcons.adn, "adn"),
  new IconDefinition(FontAwesomeIcons.bitbucket, "bitbucket"),
  new IconDefinition(FontAwesomeIcons.bitbucketSquare, "bitbucketSquare"),
  new IconDefinition(FontAwesomeIcons.tumblr, "tumblr"),
  new IconDefinition(FontAwesomeIcons.tumblrSquare, "tumblrSquare"),
  new IconDefinition(FontAwesomeIcons.longArrowDown, "longArrowDown"),
  new IconDefinition(FontAwesomeIcons.longArrowUp, "longArrowUp"),
  new IconDefinition(FontAwesomeIcons.longArrowLeft, "longArrowLeft"),
  new IconDefinition(FontAwesomeIcons.longArrowRight, "longArrowRight"),
  new IconDefinition(FontAwesomeIcons.apple, "apple"),
  new IconDefinition(FontAwesomeIcons.windows, "windows"),
  new IconDefinition(FontAwesomeIcons.android, "android"),
  new IconDefinition(FontAwesomeIcons.linux, "linux"),
  new IconDefinition(FontAwesomeIcons.dribbble, "dribbble"),
  new IconDefinition(FontAwesomeIcons.skype, "skype"),
  new IconDefinition(FontAwesomeIcons.foursquare, "foursquare"),
  new IconDefinition(FontAwesomeIcons.trello, "trello"),
  new IconDefinition(FontAwesomeIcons.female, "female"),
  new IconDefinition(FontAwesomeIcons.male, "male"),
  new IconDefinition(FontAwesomeIcons.gitTip, "gitTip"),
  new IconDefinition(FontAwesomeIcons.gratipay, "gratipay"),
  new IconDefinition(FontAwesomeIcons.sunO, "sunO"),
  new IconDefinition(FontAwesomeIcons.moonO, "moonO"),
  new IconDefinition(FontAwesomeIcons.archive, "archive"),
  new IconDefinition(FontAwesomeIcons.bug, "bug"),
  new IconDefinition(FontAwesomeIcons.vk, "vk"),
  new IconDefinition(FontAwesomeIcons.weibo, "weibo"),
  new IconDefinition(FontAwesomeIcons.renren, "renren"),
  new IconDefinition(FontAwesomeIcons.pagelines, "pagelines"),
  new IconDefinition(FontAwesomeIcons.stackExchange, "stackExchange"),
  new IconDefinition(FontAwesomeIcons.arrowCircleORight, "arrowCircleORight"),
  new IconDefinition(FontAwesomeIcons.arrowCircleOLeft, "arrowCircleOLeft"),
  new IconDefinition(FontAwesomeIcons.toggleLeft, "toggleLeft"),
  new IconDefinition(FontAwesomeIcons.caretSquareOLeft, "caretSquareOLeft"),
  new IconDefinition(FontAwesomeIcons.dotCircleO, "dotCircleO"),
  new IconDefinition(FontAwesomeIcons.wheelchair, "wheelchair"),
  new IconDefinition(FontAwesomeIcons.vimeoSquare, "vimeoSquare"),
  new IconDefinition(FontAwesomeIcons.tryCurrency, "tryCurrency"),
  new IconDefinition(FontAwesomeIcons.turkishLira, "turkishLira"),
  new IconDefinition(FontAwesomeIcons.plusSquareO, "plusSquareO"),
  new IconDefinition(FontAwesomeIcons.spaceShuttle, "spaceShuttle"),
  new IconDefinition(FontAwesomeIcons.slack, "slack"),
  new IconDefinition(FontAwesomeIcons.envelopeSquare, "envelopeSquare"),
  new IconDefinition(FontAwesomeIcons.wordpress, "wordpress"),
  new IconDefinition(FontAwesomeIcons.openid, "openid"),
  new IconDefinition(FontAwesomeIcons.bank, "bank"),
  new IconDefinition(FontAwesomeIcons.institution, "institution"),
  new IconDefinition(FontAwesomeIcons.university, "university"),
  new IconDefinition(FontAwesomeIcons.mortarBoard, "mortarBoard"),
  new IconDefinition(FontAwesomeIcons.graduationCap, "graduationCap"),
  new IconDefinition(FontAwesomeIcons.yahoo, "yahoo"),
  new IconDefinition(FontAwesomeIcons.google, "google"),
  new IconDefinition(FontAwesomeIcons.reddit, "reddit"),
  new IconDefinition(FontAwesomeIcons.redditSquare, "redditSquare"),
  new IconDefinition(FontAwesomeIcons.stumbleuponCircle, "stumbleuponCircle"),
  new IconDefinition(FontAwesomeIcons.stumbleupon, "stumbleupon"),
  new IconDefinition(FontAwesomeIcons.delicious, "delicious"),
  new IconDefinition(FontAwesomeIcons.digg, "digg"),
  new IconDefinition(FontAwesomeIcons.piedPiperPp, "piedPiperPp"),
  new IconDefinition(FontAwesomeIcons.piedPiperAlt, "piedPiperAlt"),
  new IconDefinition(FontAwesomeIcons.drupal, "drupal"),
  new IconDefinition(FontAwesomeIcons.joomla, "joomla"),
  new IconDefinition(FontAwesomeIcons.language, "language"),
  new IconDefinition(FontAwesomeIcons.fax, "fax"),
  new IconDefinition(FontAwesomeIcons.building, "building"),
  new IconDefinition(FontAwesomeIcons.child, "child"),
  new IconDefinition(FontAwesomeIcons.paw, "paw"),
  new IconDefinition(FontAwesomeIcons.spoon, "spoon"),
  new IconDefinition(FontAwesomeIcons.cube, "cube"),
  new IconDefinition(FontAwesomeIcons.cubes, "cubes"),
  new IconDefinition(FontAwesomeIcons.behance, "behance"),
  new IconDefinition(FontAwesomeIcons.behanceSquare, "behanceSquare"),
  new IconDefinition(FontAwesomeIcons.steam, "steam"),
  new IconDefinition(FontAwesomeIcons.steamSquare, "steamSquare"),
  new IconDefinition(FontAwesomeIcons.recycle, "recycle"),
  new IconDefinition(FontAwesomeIcons.automobile, "automobile"),
  new IconDefinition(FontAwesomeIcons.car, "car"),
  new IconDefinition(FontAwesomeIcons.cab, "cab"),
  new IconDefinition(FontAwesomeIcons.taxi, "taxi"),
  new IconDefinition(FontAwesomeIcons.tree, "tree"),
  new IconDefinition(FontAwesomeIcons.spotify, "spotify"),
  new IconDefinition(FontAwesomeIcons.deviantart, "deviantart"),
  new IconDefinition(FontAwesomeIcons.soundcloud, "soundcloud"),
  new IconDefinition(FontAwesomeIcons.database, "database"),
  new IconDefinition(FontAwesomeIcons.filePdfO, "filePdfO"),
  new IconDefinition(FontAwesomeIcons.fileWordO, "fileWordO"),
  new IconDefinition(FontAwesomeIcons.fileExcelO, "fileExcelO"),
  new IconDefinition(FontAwesomeIcons.filePowerpointO, "filePowerpointO"),
  new IconDefinition(FontAwesomeIcons.filePhotoO, "filePhotoO"),
  new IconDefinition(FontAwesomeIcons.filePictureO, "filePictureO"),
  new IconDefinition(FontAwesomeIcons.fileImageO, "fileImageO"),
  new IconDefinition(FontAwesomeIcons.fileZipO, "fileZipO"),
  new IconDefinition(FontAwesomeIcons.fileArchiveO, "fileArchiveO"),
  new IconDefinition(FontAwesomeIcons.fileAudioO, "fileAudioO"),
  new IconDefinition(FontAwesomeIcons.fileVideoO, "fileVideoO"),
  new IconDefinition(FontAwesomeIcons.fileCodeO, "fileCodeO"),
  new IconDefinition(FontAwesomeIcons.vine, "vine"),
  new IconDefinition(FontAwesomeIcons.codepen, "codepen"),
  new IconDefinition(FontAwesomeIcons.jsfiddle, "jsfiddle"),
  new IconDefinition(FontAwesomeIcons.lifeSaver, "lifeSaver"),
  new IconDefinition(FontAwesomeIcons.support, "support"),
  new IconDefinition(FontAwesomeIcons.circleONotch, "circleONotch"),
  new IconDefinition(FontAwesomeIcons.resistance, "resistance"),
  new IconDefinition(FontAwesomeIcons.rebel, "rebel"),
  new IconDefinition(FontAwesomeIcons.empire, "empire"),
  new IconDefinition(FontAwesomeIcons.gitSquare, "gitSquare"),
  new IconDefinition(FontAwesomeIcons.git, "git"),
  new IconDefinition(FontAwesomeIcons.yCombinatorSquare, "yCombinatorSquare"),
  new IconDefinition(FontAwesomeIcons.hackerNews, "hackerNews"),
  new IconDefinition(FontAwesomeIcons.tencentWeibo, "tencentWeibo"),
  new IconDefinition(FontAwesomeIcons.qq, "qq"),
  new IconDefinition(FontAwesomeIcons.wechat, "wechat"),
  new IconDefinition(FontAwesomeIcons.weixin, "weixin"),
  new IconDefinition(FontAwesomeIcons.send, "send"),
  new IconDefinition(FontAwesomeIcons.paperPlane, "paperPlane"),
  new IconDefinition(FontAwesomeIcons.sendO, "sendO"),
  new IconDefinition(FontAwesomeIcons.paperPlaneO, "paperPlaneO"),
  new IconDefinition(FontAwesomeIcons.history, "history"),
  new IconDefinition(FontAwesomeIcons.circleThin, "circleThin"),
  new IconDefinition(FontAwesomeIcons.header, "header"),
  new IconDefinition(FontAwesomeIcons.paragraph, "paragraph"),
  new IconDefinition(FontAwesomeIcons.sliders, "sliders"),
  new IconDefinition(FontAwesomeIcons.shareAlt, "shareAlt"),
  new IconDefinition(FontAwesomeIcons.shareAltSquare, "shareAltSquare"),
  new IconDefinition(FontAwesomeIcons.bomb, "bomb"),
  new IconDefinition(FontAwesomeIcons.soccerBallO, "soccerBallO"),
  new IconDefinition(FontAwesomeIcons.futbolO, "futbolO"),
  new IconDefinition(FontAwesomeIcons.tty, "tty"),
  new IconDefinition(FontAwesomeIcons.binoculars, "binoculars"),
  new IconDefinition(FontAwesomeIcons.plug, "plug"),
  new IconDefinition(FontAwesomeIcons.slideshare, "slideshare"),
  new IconDefinition(FontAwesomeIcons.twitch, "twitch"),
  new IconDefinition(FontAwesomeIcons.yelp, "yelp"),
  new IconDefinition(FontAwesomeIcons.newspaperO, "newspaperO"),
  new IconDefinition(FontAwesomeIcons.wifi, "wifi"),
  new IconDefinition(FontAwesomeIcons.calculator, "calculator"),
  new IconDefinition(FontAwesomeIcons.paypal, "paypal"),
  new IconDefinition(FontAwesomeIcons.googleWallet, "googleWallet"),
  new IconDefinition(FontAwesomeIcons.ccVisa, "ccVisa"),
  new IconDefinition(FontAwesomeIcons.ccMastercard, "ccMastercard"),
  new IconDefinition(FontAwesomeIcons.ccDiscover, "ccDiscover"),
  new IconDefinition(FontAwesomeIcons.ccAmex, "ccAmex"),
  new IconDefinition(FontAwesomeIcons.ccPaypal, "ccPaypal"),
  new IconDefinition(FontAwesomeIcons.ccStripe, "ccStripe"),
  new IconDefinition(FontAwesomeIcons.bellSlash, "bellSlash"),
  new IconDefinition(FontAwesomeIcons.bellSlashO, "bellSlashO"),
  new IconDefinition(FontAwesomeIcons.trash, "trash"),
  new IconDefinition(FontAwesomeIcons.copyright, "copyright"),
  new IconDefinition(FontAwesomeIcons.at, "at"),
  new IconDefinition(FontAwesomeIcons.eyedropper, "eyedropper"),
  new IconDefinition(FontAwesomeIcons.paintBrush, "paintBrush"),
  new IconDefinition(FontAwesomeIcons.birthdayCake, "birthdayCake"),
  new IconDefinition(FontAwesomeIcons.areaChart, "areaChart"),
  new IconDefinition(FontAwesomeIcons.pieChart, "pieChart"),
  new IconDefinition(FontAwesomeIcons.lineChart, "lineChart"),
  new IconDefinition(FontAwesomeIcons.lastfm, "lastfm"),
  new IconDefinition(FontAwesomeIcons.lastfmSquare, "lastfmSquare"),
  new IconDefinition(FontAwesomeIcons.toggleOff, "toggleOff"),
  new IconDefinition(FontAwesomeIcons.toggleOn, "toggleOn"),
  new IconDefinition(FontAwesomeIcons.bicycle, "bicycle"),
  new IconDefinition(FontAwesomeIcons.bus, "bus"),
  new IconDefinition(FontAwesomeIcons.ioxhost, "ioxhost"),
  new IconDefinition(FontAwesomeIcons.angellist, "angellist"),
  new IconDefinition(FontAwesomeIcons.cc, "cc"),
  new IconDefinition(FontAwesomeIcons.shekel, "shekel"),
  new IconDefinition(FontAwesomeIcons.ils, "ils"),
  new IconDefinition(FontAwesomeIcons.meanpath, "meanpath"),
  new IconDefinition(FontAwesomeIcons.buysellads, "buysellads"),
  new IconDefinition(FontAwesomeIcons.connectdevelop, "connectdevelop"),
  new IconDefinition(FontAwesomeIcons.dashcube, "dashcube"),
  new IconDefinition(FontAwesomeIcons.forumbee, "forumbee"),
  new IconDefinition(FontAwesomeIcons.leanpub, "leanpub"),
  new IconDefinition(FontAwesomeIcons.sellsy, "sellsy"),
  new IconDefinition(FontAwesomeIcons.shirtsinbulk, "shirtsinbulk"),
  new IconDefinition(FontAwesomeIcons.simplybuilt, "simplybuilt"),
  new IconDefinition(FontAwesomeIcons.skyatlas, "skyatlas"),
  new IconDefinition(FontAwesomeIcons.cartPlus, "cartPlus"),
  new IconDefinition(FontAwesomeIcons.cartArrowDown, "cartArrowDown"),
  new IconDefinition(FontAwesomeIcons.diamond, "diamond"),
  new IconDefinition(FontAwesomeIcons.ship, "ship"),
  new IconDefinition(FontAwesomeIcons.userSecret, "userSecret"),
  new IconDefinition(FontAwesomeIcons.motorcycle, "motorcycle"),
  new IconDefinition(FontAwesomeIcons.streetView, "streetView"),
  new IconDefinition(FontAwesomeIcons.heartbeat, "heartbeat"),
  new IconDefinition(FontAwesomeIcons.venus, "venus"),
  new IconDefinition(FontAwesomeIcons.mars, "mars"),
  new IconDefinition(FontAwesomeIcons.mercury, "mercury"),
  new IconDefinition(FontAwesomeIcons.intersex, "intersex"),
  new IconDefinition(FontAwesomeIcons.transgender, "transgender"),
  new IconDefinition(FontAwesomeIcons.transgenderAlt, "transgenderAlt"),
  new IconDefinition(FontAwesomeIcons.venusDouble, "venusDouble"),
  new IconDefinition(FontAwesomeIcons.marsDouble, "marsDouble"),
  new IconDefinition(FontAwesomeIcons.venusMars, "venusMars"),
  new IconDefinition(FontAwesomeIcons.marsStroke, "marsStroke"),
  new IconDefinition(FontAwesomeIcons.marsStrokeV, "marsStrokeV"),
  new IconDefinition(FontAwesomeIcons.marsStrokeH, "marsStrokeH"),
  new IconDefinition(FontAwesomeIcons.neuter, "neuter"),
  new IconDefinition(FontAwesomeIcons.genderless, "genderless"),
  new IconDefinition(FontAwesomeIcons.facebookOfficial, "facebookOfficial"),
  new IconDefinition(FontAwesomeIcons.pinterestP, "pinterestP"),
  new IconDefinition(FontAwesomeIcons.whatsapp, "whatsapp"),
  new IconDefinition(FontAwesomeIcons.server, "server"),
  new IconDefinition(FontAwesomeIcons.userPlus, "userPlus"),
  new IconDefinition(FontAwesomeIcons.userTimes, "userTimes"),
  new IconDefinition(FontAwesomeIcons.hotel, "hotel"),
  new IconDefinition(FontAwesomeIcons.bed, "bed"),
  new IconDefinition(FontAwesomeIcons.viacoin, "viacoin"),
  new IconDefinition(FontAwesomeIcons.train, "train"),
  new IconDefinition(FontAwesomeIcons.subway, "subway"),
  new IconDefinition(FontAwesomeIcons.medium, "medium"),
  new IconDefinition(FontAwesomeIcons.yCombinator, "yCombinator"),
  new IconDefinition(FontAwesomeIcons.optinMonster, "optinMonster"),
  new IconDefinition(FontAwesomeIcons.opencart, "opencart"),
  new IconDefinition(FontAwesomeIcons.expeditedssl, "expeditedssl"),
  new IconDefinition(FontAwesomeIcons.battery, "battery"),
  new IconDefinition(FontAwesomeIcons.batteryFull, "batteryFull"),
  new IconDefinition(
      FontAwesomeIcons.batteryThreeQuarters, "batteryThreeQuarters"),
  new IconDefinition(FontAwesomeIcons.batteryHalf, "batteryHalf"),
  new IconDefinition(FontAwesomeIcons.batteryQuarter, "batteryQuarter"),
  new IconDefinition(FontAwesomeIcons.batteryEmpty, "batteryEmpty"),
  new IconDefinition(FontAwesomeIcons.mousePointer, "mousePointer"),
  new IconDefinition(FontAwesomeIcons.iCursor, "iCursor"),
  new IconDefinition(FontAwesomeIcons.objectGroup, "objectGroup"),
  new IconDefinition(FontAwesomeIcons.objectUngroup, "objectUngroup"),
  new IconDefinition(FontAwesomeIcons.stickyNote, "stickyNote"),
  new IconDefinition(FontAwesomeIcons.stickyNoteO, "stickyNoteO"),
  new IconDefinition(FontAwesomeIcons.ccJcb, "ccJcb"),
  new IconDefinition(FontAwesomeIcons.ccDinersClub, "ccDinersClub"),
  new IconDefinition(FontAwesomeIcons.clone, "clone"),
  new IconDefinition(FontAwesomeIcons.balanceScale, "balanceScale"),
  new IconDefinition(FontAwesomeIcons.hourglassO, "hourglassO"),
  new IconDefinition(FontAwesomeIcons.hourglassFull, "hourglassFull"),
  new IconDefinition(FontAwesomeIcons.hourglassHalf, "hourglassHalf"),
  new IconDefinition(FontAwesomeIcons.hourglassEmpty, "hourglassEmpty"),
  new IconDefinition(FontAwesomeIcons.hourglass, "hourglass"),
  new IconDefinition(FontAwesomeIcons.handGrabO, "handGrabO"),
  new IconDefinition(FontAwesomeIcons.handRockO, "handRockO"),
  new IconDefinition(FontAwesomeIcons.handStopO, "handStopO"),
  new IconDefinition(FontAwesomeIcons.handPaperO, "handPaperO"),
  new IconDefinition(FontAwesomeIcons.handScissorsO, "handScissorsO"),
  new IconDefinition(FontAwesomeIcons.handLizardO, "handLizardO"),
  new IconDefinition(FontAwesomeIcons.handSpockO, "handSpockO"),
  new IconDefinition(FontAwesomeIcons.handPointerO, "handPointerO"),
  new IconDefinition(FontAwesomeIcons.handPeaceO, "handPeaceO"),
  new IconDefinition(FontAwesomeIcons.trademark, "trademark"),
  new IconDefinition(FontAwesomeIcons.registered, "registered"),
  new IconDefinition(FontAwesomeIcons.creativeCommons, "creativeCommons"),
  new IconDefinition(FontAwesomeIcons.gg, "gg"),
  new IconDefinition(FontAwesomeIcons.ggCircle, "ggCircle"),
  new IconDefinition(FontAwesomeIcons.tripadvisor, "tripadvisor"),
  new IconDefinition(FontAwesomeIcons.odnoklassniki, "odnoklassniki"),
  new IconDefinition(
      FontAwesomeIcons.odnoklassnikiSquare, "odnoklassnikiSquare"),
  new IconDefinition(FontAwesomeIcons.getPocket, "getPocket"),
  new IconDefinition(FontAwesomeIcons.wikipediaW, "wikipediaW"),
  new IconDefinition(FontAwesomeIcons.safari, "safari"),
  new IconDefinition(FontAwesomeIcons.chrome, "chrome"),
  new IconDefinition(FontAwesomeIcons.firefox, "firefox"),
  new IconDefinition(FontAwesomeIcons.opera, "opera"),
  new IconDefinition(FontAwesomeIcons.internetExplorer, "internetExplorer"),
  new IconDefinition(FontAwesomeIcons.television, "television"),
  new IconDefinition(FontAwesomeIcons.contao, "contao"),
  new IconDefinition(FontAwesomeIcons.fiveHundredPx, "fiveHundredPx"),
  new IconDefinition(FontAwesomeIcons.amazon, "amazon"),
  new IconDefinition(FontAwesomeIcons.calendarPlusO, "calendarPlusO"),
  new IconDefinition(FontAwesomeIcons.calendarMinusO, "calendarMinusO"),
  new IconDefinition(FontAwesomeIcons.calendarTimesO, "calendarTimesO"),
  new IconDefinition(FontAwesomeIcons.calendarCheckO, "calendarCheckO"),
  new IconDefinition(FontAwesomeIcons.industry, "industry"),
  new IconDefinition(FontAwesomeIcons.mapPin, "mapPin"),
  new IconDefinition(FontAwesomeIcons.mapSigns, "mapSigns"),
  new IconDefinition(FontAwesomeIcons.mapO, "mapO"),
  new IconDefinition(FontAwesomeIcons.map, "map"),
  new IconDefinition(FontAwesomeIcons.commenting, "commenting"),
  new IconDefinition(FontAwesomeIcons.commentingO, "commentingO"),
  new IconDefinition(FontAwesomeIcons.houzz, "houzz"),
  new IconDefinition(FontAwesomeIcons.vimeo, "vimeo"),
  new IconDefinition(FontAwesomeIcons.blackTie, "blackTie"),
  new IconDefinition(FontAwesomeIcons.fonticons, "fonticons"),
  new IconDefinition(FontAwesomeIcons.redditAlien, "redditAlien"),
  new IconDefinition(FontAwesomeIcons.edge, "edge"),
  new IconDefinition(FontAwesomeIcons.creditCardAlt, "creditCardAlt"),
  new IconDefinition(FontAwesomeIcons.codiepie, "codiepie"),
  new IconDefinition(FontAwesomeIcons.modx, "modx"),
  new IconDefinition(FontAwesomeIcons.fortAwesome, "fortAwesome"),
  new IconDefinition(FontAwesomeIcons.usb, "usb"),
  new IconDefinition(FontAwesomeIcons.productHunt, "productHunt"),
  new IconDefinition(FontAwesomeIcons.mixcloud, "mixcloud"),
  new IconDefinition(FontAwesomeIcons.scribd, "scribd"),
  new IconDefinition(FontAwesomeIcons.pauseCircle, "pauseCircle"),
  new IconDefinition(FontAwesomeIcons.pauseCircleO, "pauseCircleO"),
  new IconDefinition(FontAwesomeIcons.stopCircle, "stopCircle"),
  new IconDefinition(FontAwesomeIcons.stopCircleO, "stopCircleO"),
  new IconDefinition(FontAwesomeIcons.shoppingBag, "shoppingBag"),
  new IconDefinition(FontAwesomeIcons.shoppingBasket, "shoppingBasket"),
  new IconDefinition(FontAwesomeIcons.hashtag, "hashtag"),
  new IconDefinition(FontAwesomeIcons.bluetooth, "bluetooth"),
  new IconDefinition(FontAwesomeIcons.bluetoothB, "bluetoothB"),
  new IconDefinition(FontAwesomeIcons.percent, "percent"),
  new IconDefinition(FontAwesomeIcons.gitlab, "gitlab"),
  new IconDefinition(FontAwesomeIcons.wpbeginner, "wpbeginner"),
  new IconDefinition(FontAwesomeIcons.wpforms, "wpforms"),
  new IconDefinition(FontAwesomeIcons.envira, "envira"),
  new IconDefinition(FontAwesomeIcons.universalAccess, "universalAccess"),
  new IconDefinition(FontAwesomeIcons.wheelchairAlt, "wheelchairAlt"),
  new IconDefinition(FontAwesomeIcons.questionCircleO, "questionCircleO"),
  new IconDefinition(FontAwesomeIcons.blind, "blind"),
  new IconDefinition(FontAwesomeIcons.audioDescription, "audioDescription"),
  new IconDefinition(FontAwesomeIcons.volumeControlPhone, "volumeControlPhone"),
  new IconDefinition(FontAwesomeIcons.braille, "braille"),
  new IconDefinition(
      FontAwesomeIcons.assistiveListeningSystems, "assistiveListeningSystems"),
  new IconDefinition(FontAwesomeIcons.americanSignLanguageInterpreting,
      "americanSignLanguageInterpreting"),
  new IconDefinition(FontAwesomeIcons.deaf, "deaf"),
  new IconDefinition(FontAwesomeIcons.glide, "glide"),
  new IconDefinition(FontAwesomeIcons.glideG, "glideG"),
  new IconDefinition(FontAwesomeIcons.signLanguage, "signLanguage"),
  new IconDefinition(FontAwesomeIcons.lowVision, "lowVision"),
  new IconDefinition(FontAwesomeIcons.viadeo, "viadeo"),
  new IconDefinition(FontAwesomeIcons.viadeoSquare, "viadeoSquare"),
  new IconDefinition(FontAwesomeIcons.snapchat, "snapchat"),
  new IconDefinition(FontAwesomeIcons.snapchatGhost, "snapchatGhost"),
  new IconDefinition(FontAwesomeIcons.snapchatSquare, "snapchatSquare"),
  new IconDefinition(FontAwesomeIcons.piedPiper, "piedPiper"),
  new IconDefinition(FontAwesomeIcons.firstOrder, "firstOrder"),
  new IconDefinition(FontAwesomeIcons.yoast, "yoast"),
  new IconDefinition(FontAwesomeIcons.themeisle, "themeisle"),
  new IconDefinition(FontAwesomeIcons.googlePlusOfficial, "googlePlusOfficial"),
  new IconDefinition(FontAwesomeIcons.fontAwesome, "fontAwesome"),
  new IconDefinition(FontAwesomeIcons.handshakeO, "handshakeO"),
  new IconDefinition(FontAwesomeIcons.envelopeOpen, "envelopeOpen"),
  new IconDefinition(FontAwesomeIcons.envelopeOpenO, "envelopeOpenO"),
  new IconDefinition(FontAwesomeIcons.linode, "linode"),
  new IconDefinition(FontAwesomeIcons.addressBook, "addressBook"),
  new IconDefinition(FontAwesomeIcons.addressBookO, "addressBookO"),
  new IconDefinition(FontAwesomeIcons.vCard, "vCard"),
  new IconDefinition(FontAwesomeIcons.addressCard, "addressCard"),
  new IconDefinition(FontAwesomeIcons.vCardO, "vCardO"),
  new IconDefinition(FontAwesomeIcons.addressCardO, "addressCardO"),
  new IconDefinition(FontAwesomeIcons.userCircle, "userCircle"),
  new IconDefinition(FontAwesomeIcons.userCircleO, "userCircleO"),
  new IconDefinition(FontAwesomeIcons.userO, "userO"),
  new IconDefinition(FontAwesomeIcons.idBadge, "idBadge"),
  new IconDefinition(FontAwesomeIcons.driversLicense, "driversLicense"),
  new IconDefinition(FontAwesomeIcons.idCard, "idCard"),
  new IconDefinition(FontAwesomeIcons.driversLicenseO, "driversLicenseO"),
  new IconDefinition(FontAwesomeIcons.idCardO, "idCardO"),
  new IconDefinition(FontAwesomeIcons.quora, "quora"),
  new IconDefinition(FontAwesomeIcons.freeCodeCamp, "freeCodeCamp"),
  new IconDefinition(FontAwesomeIcons.telegram, "telegram"),
  new IconDefinition(FontAwesomeIcons.thermometer, "thermometer"),
  new IconDefinition(FontAwesomeIcons.thermometerFull, "thermometerFull"),
  new IconDefinition(
      FontAwesomeIcons.thermometerThreeQuarters, "thermometerThreeQuarters"),
  new IconDefinition(FontAwesomeIcons.thermometerHalf, "thermometerHalf"),
  new IconDefinition(FontAwesomeIcons.thermometerQuarter, "thermometerQuarter"),
  new IconDefinition(FontAwesomeIcons.thermometerEmpty, "thermometerEmpty"),
  new IconDefinition(FontAwesomeIcons.shower, "shower"),
  new IconDefinition(FontAwesomeIcons.bathtub, "bathtub"),
  new IconDefinition(FontAwesomeIcons.podcast, "podcast"),
  new IconDefinition(FontAwesomeIcons.windowMaximize, "windowMaximize"),
  new IconDefinition(FontAwesomeIcons.windowMinimize, "windowMinimize"),
  new IconDefinition(FontAwesomeIcons.windowRestore, "windowRestore"),
  new IconDefinition(FontAwesomeIcons.timesRectangle, "timesRectangle"),
  new IconDefinition(FontAwesomeIcons.windowClose, "windowClose"),
  new IconDefinition(FontAwesomeIcons.timesRectangleO, "timesRectangleO"),
  new IconDefinition(FontAwesomeIcons.windowCloseO, "windowCloseO"),
  new IconDefinition(FontAwesomeIcons.bandcamp, "bandcamp"),
  new IconDefinition(FontAwesomeIcons.grav, "grav"),
  new IconDefinition(FontAwesomeIcons.etsy, "etsy"),
  new IconDefinition(FontAwesomeIcons.imdb, "imdb"),
  new IconDefinition(FontAwesomeIcons.ravelry, "ravelry"),
  new IconDefinition(FontAwesomeIcons.eercast, "eercast"),
  new IconDefinition(FontAwesomeIcons.microchip, "microchip"),
  new IconDefinition(FontAwesomeIcons.snowflakeO, "snowflakeO"),
  new IconDefinition(FontAwesomeIcons.superpowers, "superpowers"),
  new IconDefinition(FontAwesomeIcons.wpexplorer, "wpexplorer"),
  new IconDefinition(FontAwesomeIcons.meetup, "meetup"),
];

class IconDefinition implements Comparable {
  final IconData iconData;
  final String title;

  IconDefinition(this.iconData, this.title);

  @override
  String toString() => 'IconDefinition{iconData: $iconData, title: $title}';

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is IconDefinition &&
          runtimeType == other.runtimeType &&
          iconData == other.iconData &&
          title == other.title;

  @override
  int get hashCode => iconData.hashCode ^ title.hashCode;

  @override
  int compareTo(other) => title.compareTo(other.title);
}
